@@ -1,6 +1,6 @@
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
-# For details: https://github.com/PyCQA/astroid/blob/main/LICENSE
-# Copyright (c) https://github.com/PyCQA/astroid/blob/main/CONTRIBUTORS.txt
+# For details: https://github.com/pylint-dev/astroid/blob/main/LICENSE
+# Copyright (c) https://github.com/pylint-dev/astroid/blob/main/CONTRIBUTORS.txt
 
 from __future__ import annotations
 
@@ -8,12 +8,10 @@ from astroid import builder
 
 
 def test_pytest() -> None:
-    ast_node = builder.extract_node(
-        """
+    ast_node = builder.extract_node("""
     import pytest
     pytest #@
-    """
-    )
+    """)
     module = next(ast_node.infer())
     attrs = [
         "deprecated_call",
