@@ -3,6 +3,7 @@
 # Copyright (c) https://github.com/pylint-dev/astroid/blob/main/CONTRIBUTORS.txt
 
 """Unit tests for module modutils (module manipulation utilities)."""
+
 import email
 import logging
 import os
@@ -151,6 +152,31 @@ class GetModulePartTest(unittest.TestCase):
         self.assertEqual(modutils.get_module_part(".", modutils.__file__), ".")
 
 
+class IsSubpathTest(unittest.TestCase):
+    """Tests for modutils._is_subpath,
+    which is used internally by modutils.modpath_from_file."""
+
+    @unittest.skipUnless(sys.platform == "win32", "Windows-specific path test")
+    def test_is_subpath_with_trailing_separator_unc_path(self) -> None:
+        self.assertTrue(
+            modutils._is_subpath(
+                "\\\\Mac\\Code\\tests\\test_resources.py",
+                # UNC path with trailing separator
+                "\\\\mac\\code\\",
+            )
+        )
+
+    @unittest.skipUnless(sys.platform == "win32", "Windows-specific path test")
+    def test_is_subpath_without_trailing_separator_unc_path(self) -> None:
+        self.assertTrue(
+            modutils._is_subpath(
+                "\\\\Mac\\Code\\tests\\test_resources.py",
+                # UNC path without trailing separator
+                "\\\\mac\\code",
+            )
+        )
+
+
 class ModPathFromFileTest(unittest.TestCase):
     """Given an absolute file path return the python module's path as a list."""
 
